<p align="center">
  <img src="assets/notebook.png">
</p>

<div align="center">

[![forthebadge](https://forthebadge.com/images/badges/for-sharks.svg)](https://forthebadge.com)
[![forthebadge](https://forthebadge.com/images/badges/60-percent-of-the-time-works-every-time.svg)](https://forthebadge.com)
[![forthebadge](https://forthebadge.com/images/badges/no-ragrets.svg)](https://forthebadge.com)

</div>
